@@ -11,7 +11,7 @@ export default function PropertyToggle(_ref) {
 
   return React.createElement(
     'div',
-    { style: { marginBottom: "3px" } },
+    { className: 'PropertyToggle', style: { marginBottom: "3px" } },
     React.createElement(
       'div',
       { style: { display: "inline-block", width: "30%" } },
