@@ -3,6 +3,7 @@ import { Map, List } from 'immutable';
 import { sceneSnapElements } from '../utils/snap-scene';
 import { nearestSnap } from '../utils/snap';
 import { detectAndUpdateAreas, removeLine, addLineAvoidingIntersections, mergeEqualsVertices } from '../utils/layer-operations';
+import { orderVertices, pointsDistance } from "../utils/geometry";
 
 export default function (state, action) {
   switch (action.type) {
@@ -61,17 +62,63 @@ function updateDraggingVertex(state, x, y, detectSnap) {
 function endDraggingVertex(state, x, y, detectSnap) {
   var catalog = state.catalog;
 
-  var _state = state,
-      draggingSupport = _state.draggingSupport;
+  var draggingSupport = state.draggingSupport;
 
   var layerID = draggingSupport.get('layerID');
   var vertexID = draggingSupport.get('vertexID');
   var lineIDs = state.scene.layers.get(layerID).vertices.get(vertexID).lines;
 
-  /** TODO: remove this **/
-  state = updateDraggingVertex(state, x, y, detectSnap);
   var scene = state.scene.updateIn(['layers', layerID], function (layer) {
-    return mergeEqualsVertices(layer, vertexID);
+    return layer.withMutations(function (layer) {
+
+      lineIDs.forEach(function (lineID) {
+        var line = layer.lines.get(lineID);
+
+        if (line) {
+          (function () {
+
+            var oldVertexID = void 0;
+
+            if (line.vertices.get(0) === vertexID) {
+              // I need to invert vertices
+              oldVertexID = line.vertices.get(1);
+            } else {
+              oldVertexID = line.vertices.get(0);
+            }
+
+            var oldVertex = layer.vertices.get(oldVertexID);
+            var vertex = layer.vertices.get(vertexID);
+
+            var oldHoles = [];
+
+            var orderedVertices = orderVertices([oldVertex, vertex]);
+
+            line.holes.forEach(function (holeID) {
+              var hole = layer.holes.get(holeID);
+              var oldLineLength = pointsDistance(oldVertex.x, oldVertex.y, vertex.x, vertex.y);
+
+              var alpha = Math.atan2(orderedVertices[1].y - orderedVertices[0].y, orderedVertices[1].x - orderedVertices[0].x);
+
+              var offset = hole.offset;
+
+              if (orderedVertices[1].x === line.vertices.get(1).x && orderedVertices[1].y === line.vertices(1).y) {
+                offset = 1 - offset;
+              }
+
+              var xp = oldLineLength * offset * Math.cos(alpha) + orderedVertices[0].x;
+              var yp = oldLineLength * offset * Math.sin(alpha) + orderedVertices[0].y;
+
+              oldHoles.push({ hole: hole, offsetPosition: { x: xp, y: yp } });
+            });
+
+            removeLine(layer, lineID);
+            addLineAvoidingIntersections(layer, line.type, oldVertex.x, oldVertex.y, vertex.x, vertex.y, catalog, line.properties, oldHoles);
+          })();
+        }
+      });
+
+      detectAndUpdateAreas(layer, catalog);
+    });
   });
 
   return state.merge({
@@ -83,43 +130,4 @@ function endDraggingVertex(state, x, y, detectSnap) {
     snapElements: new List(),
     sceneHistory: state.sceneHistory.push(scene)
   });
-
-  /** end TODO **/
-
-  // let scene = state.scene.updateIn(['layers', layerID], layer => layer.withMutations(layer => {
-  //
-  //   lineIDs.forEach(lineID => {
-  //     let line = layer.lines.get(lineID);
-  //
-  //     if (line) {
-  //
-  //       let oldVertexID;
-  //
-  //       if (line.vertices.get(0) === vertexID) {
-  //         // I need to invert vertices
-  //         oldVertexID = line.vertices.get(1);
-  //       } else {
-  //         oldVertexID = line.vertices.get(0);
-  //       }
-  //
-  //       let oldVertex = layer.vertices.get(oldVertexID);
-  //       let vertex = layer.vertices.get(vertexID);
-  //
-  //       removeLine(layer, lineID);
-  //       addLineAvoidingIntersections(layer, line.type, oldVertex.x, oldVertex.y, vertex.x, vertex.y, catalog, line.properties);
-  //     }
-  //   });
-  //
-  //   detectAndUpdateAreas(layer, catalog);
-  // }));
-  //
-  // return state.merge({
-  //   mode: MODE_IDLE,
-  //   draggingSupport: null,
-  //   scene,
-  //
-  //   activeSnapElement: null,
-  //   snapElements: new List(),
-  //   sceneHistory: state.sceneHistory.push(scene)
-  // });
 }
\ No newline at end of file
