@@ -175,6 +175,12 @@ function updateRotatingItem(state, x, y) {
   let deltaY = y - item.y;
   let rotation = Math.atan2(deltaY, deltaX) * 180 / Math.PI - 90;
 
+  if (-5 < rotation && rotation < 5) rotation = 0;
+  if (-95 < rotation && rotation < -85) rotation = -90;
+  if (-185 < rotation && rotation < -175) rotation = -180;
+  if (85 < rotation && rotation < 90) rotation = 90;
+  if (-270 < rotation && rotation < -265) rotation = 90;
+
   item = item.merge({
     rotation,
   });
